pub struct CoverageFixer { /* private fields */ }Expand description
Fix coverage information based on source code
You MUST fix coverage information using this struct because Rules require coverage informations to be stored in correct format. This struct checks the information format and modify it if it is invalid.
Implementations